package com.link.core.converter;

import com.link.core.converter.util.Assert;
import com.link.core.converter.util.ExceptionUtil;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class ConverterUtil {
   public static <S, T> List<T> convert(Collection<? extends S> sources, Converter<S, T> converter) throws IllegalArgumentException, ConversionException {
      Assert.assertArgumentNotNull(converter, "converter");
      return ArrayListConverter.newConverter(converter).convert(sources);
   }

   public static <S, T> List<T> exhaustedlyConvert(Collection<? extends S> sources, Converter<S, T> converter) throws IllegalArgumentException, ConversionException {
      Assert.assertArgumentNotNull(converter, "converter");
      return ArrayListConverter.newConverter(converter).setOptimal(false).convert(sources);
   }

   public static <S, T> void inject(Collection<? extends S> sources, Collection<T> targets, Injector<S, T> injector) throws IllegalArgumentException, ConversionException {
      if (sources != null && targets != null) {
         if (injector == null) {
            throw ExceptionUtil.nullArgument("injector");
         } else {
            Iterator<?> sourceIterator = sources.iterator();
            Iterator<T> targetIterator = targets.iterator();

            while(targetIterator.hasNext() && sourceIterator.hasNext()) {
               S source = sourceIterator.next();
               T target = targetIterator.next();
               injector.inject(source, target);
            }

         }
      }
   }
}
